@@ -167,14 +167,13 @@ PIDFile=/var/run/{pidfile}.pid
 WorkingDirectory={working_dir}
 User={user}
 Group={user}
-StandardOutput=syslog+console
-StandardError=syslog+console
+StandardOutput=syslog
+StandardError=syslog
 Restart=on-failure
 ExecStart={executable} {serve} {args}
 ExecReload=/bin/kill -s HUP $MAINPID
 RestartSec=2s
 TimeoutStopSec=5
-PrivateTmp=true
 KillMode=mixed
 
 [Install]
